@@ -302,7 +302,7 @@ class Resource(object):
             isinstance(response_body, requests.Response)
             and response_body.status_code == 303
         ):
-            self._overwrite(redirect=response_body.headers["Location"])
+            self._overwrite(id=self.id, redirect=response_body.headers["Location"])
         else:
             self._overwrite(
                 included=response_body.get("included"), **response_body["data"]
@@ -405,6 +405,7 @@ class Resource(object):
     filter = _collection_method("filter")
     page = _collection_method("page")
     include = _collection_method("include")
+    limit = _collection_method("limit")
     sort = _collection_method("sort")
     fields = _collection_method("fields")
     extra = _collection_method("extra")
